==> haskell-cabal-doctest-1.0.2-2-i686.pkg.tar.xz: usr/share/haskell/register/haskell-cabal-doctest.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cabal-doctest
version: 1.0.2
id: cabal-doctest-1.0.2-Bl80n9TxTYEBsBCKM9EFAB
key: cabal-doctest-1.0.2-Bl80n9TxTYEBsBCKM9EFAB
license: BSD3
copyright: (c) 2017 Oleg Grenrus
maintainer: Oleg Grenrus <oleg.grenrus@iki.fi>
homepage: https://github.com/phadej/cabal-doctest
synopsis: A Setup.hs helper for doctests running
description:
    Currently (beginning of 2017), there isn'\''t @cabal doctest@
    command. Yet, to properly work doctest needs plenty of configuration.
    This library provides the common bits for writing custom Setup.hs
    See <https://github.com/haskell/cabal/issues/2327 Cabal/2327> for the progress
    of @cabal doctest@, i.e. whether this library is obsolete.
category: Distribution
author: Oleg Grenrus <oleg.grenrus@iki.fi>
exposed: True
indefinite: False
exposed-modules:
    Distribution.Extra.Doctest
abi: 787f4fca17f50a1ec98d5583ac605e6a
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/cabal-doctest-1.0.2
library-dirs: /usr/lib/ghc-8.2.1/site-local/cabal-doctest-1.0.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.2.1/cabal-doctest-1.0.2
hs-libraries: HScabal-doctest-1.0.2-Bl80n9TxTYEBsBCKM9EFAB
depends:
    base-4.10.0.0 Cabal-2.0.0.2 filepath-1.4.1.2 directory-1.3.0.2
abi-depends: base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
             Cabal-2.0.0.2=a2520fd25489686ee7e9d64a6ce11828
             filepath-1.4.1.2=2a8b7688454d81e83f77ef81b74e0636
             directory-1.3.0.2=cfeb01f7201df723a8082d0da3163aee
haddock-interfaces: /usr/share/doc/haskell-cabal-doctest/html/cabal-doctest.haddock
haddock-html: /usr/share/doc/haskell-cabal-doctest/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-cabal-doctest-1.0.3-1-i686.pkg.tar.xz: usr/share/haskell/register/haskell-cabal-doctest.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cabal-doctest
version: 1.0.3
id: cabal-doctest-1.0.3-GKOjtCgApo4EHm3oXutYKW
key: cabal-doctest-1.0.3-GKOjtCgApo4EHm3oXutYKW
license: BSD3
copyright: (c) 2017 Oleg Grenrus
maintainer: Oleg Grenrus <oleg.grenrus@iki.fi>
homepage: https://github.com/phadej/cabal-doctest
synopsis: A Setup.hs helper for doctests running
description:
    Currently (beginning of 2017), there isn'\''t @cabal doctest@
    command. Yet, to properly work doctest needs plenty of configuration.
    This library provides the common bits for writing custom Setup.hs
    See <https://github.com/haskell/cabal/issues/2327 Cabal/2327> for the progress
    of @cabal doctest@, i.e. whether this library is obsolete.
category: Distribution
author: Oleg Grenrus <oleg.grenrus@iki.fi>
exposed: True
indefinite: False
exposed-modules:
    Distribution.Extra.Doctest
abi: af187f09e2c5e9bb2902dc99bab0c4e1
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/cabal-doctest-1.0.3
library-dirs: /usr/lib/ghc-8.2.1/site-local/cabal-doctest-1.0.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.2.1/cabal-doctest-1.0.3
hs-libraries: HScabal-doctest-1.0.3-GKOjtCgApo4EHm3oXutYKW
depends:
    base-4.10.0.0 Cabal-2.0.0.2 filepath-1.4.1.2 directory-1.3.0.2
abi-depends: base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
             Cabal-2.0.0.2=a2520fd25489686ee7e9d64a6ce11828
             filepath-1.4.1.2=2a8b7688454d81e83f77ef81b74e0636
             directory-1.3.0.2=cfeb01f7201df723a8082d0da3163aee
haddock-interfaces: /usr/share/doc/haskell-cabal-doctest/html/cabal-doctest.haddock
haddock-html: /usr/share/doc/haskell-cabal-doctest/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
